
//_______________________________________________________________________________________________________________
/****************************************************************************************************************/
/*                                                                                                              */
/*                     S I M P L E     M E S S A G E S                                                          */
/*                                                                                                              */
/****************************************************************************************************************/

//------------------------------------------------------------------------------
// Check for message exists

#define OS_CheckSMsg(smsg)       (smsg != (OST_SMSG)0)

//------------------------------------------------------------------------------
// Check for message is free

#define OS_IsSMsgFree(smsg)       (smsg == (OST_SMSG)0)

//------------------------------------------------------------------------------
// Clear message (internal system service)

#define _OS_MakeSMsgFree(smsg)          smsg = (OST_SMSG)0

//------------------------------------------------------------------------------
// Create simple message 

#define OS_CreateSMsg(smsg)             smsg = (OST_SMSG)0

//------------------------------------------------------------------------------
// Send simple message. If message already exists then wait when it became free.

#define OS_SendSMsg(smsg, message)                                      \
    {                                                                   \
        if (OS_CheckSMsg(smsg))                                         \
            _OS_WAIT_EVENT(OS_IsSMsgFree(smsg));                        \
        smsg = (OST_SMSG) message;                                      \
    }

//------------------------------------------------------------------------------
// Send simple message. If message already exists then it will be overwritten.

#define OS_SendSMsgNoWait(smsg, message)                                \
    {                                                                   \
        __OS_MSG_DI();                                                  \
        OS_Flags.bEventError = 0;                                       \
        if (OS_CheckSMsg(smsg)) OS_Flags.bEventError = 1;               \
        smsg = (OST_SMSG) message;                                      \
        __OS_MSG_RI();                                                  \
    }


//------------------------------------------------------------------------------
#ifdef OS_ENABLE_INT_SERVICE
// Send simple message. If message already exists then it will be overwritten.

#define OS_IntSendSMsgNoWait(smsg, message)                             \
    {                                                                   \
        OS_Flags.bEventError = 0;                                       \
        if (OS_CheckSMsg(smsg)) OS_Flags.bEventError = 1;               \
        smsg = (OST_SMSG) message;                                      \
    }
#endif

//------------------------------------------------------------------------------
// Send simple message. If message already exists then wait when it became free. 
// Exit if timeout expired.

#define OS_SendSMsgTimeout(smsg, message, timeout)                  \
    {                                                               \
        if (OS_CheckSMsg(smsg))                                     \
        {                                                           \
            _OS_WAIT_EVENT_TIMEOUT(OS_IsSMsgFree(smsg), timeout);   \
            if (!OS_IsTimeout()) {                                  \
                smsg = (OST_SMSG) message;                          \
            }                                                       \
        } else {                                                    \
            smsg = (OST_SMSG) message;                              \
        }                                                           \
    }                                                    


//------------------------------------------------------------------------------
// Wait for simple message. After accepting simple message is cleared.

#define OS_WaitSMsg(smsg, os_smsg_type_var)                         \
    {                                                               \
        _OS_WAIT_EVENT(OS_CheckSMsg(smsg));                         \
        os_smsg_type_var = smsg;                                    \
        _OS_MakeSMsgFree(smsg);                                     \
    }


//------------------------------------------------------------------------------
// Wait for simple message. After accepting simple message is cleared. Exit if timeout expired.

#define OS_WaitSMsgTimeout(smsg, os_smsg_type_var, timeout)         \
    {                                                               \
        _OS_WAIT_EVENT_TIMEOUT(OS_CheckSMsg(smsg), timeout);        \
        if (!OS_IsTimeout()) {                                      \
            os_smsg_type_var = smsg;                                \
            _OS_MakeSMsgFree(smsg);                                 \
        }                                                           \
    }

//------------------------------------------------------------------------------
// Accept existing simple message. After accepting message is cleared.

#define OS_AcceptSMsg(smsg, os_smsg_type_var)                       \
    {                                                               \
        os_smsg_type_var = smsg;                                    \
        _OS_MakeSMsgFree(smsg);                                     \
    }





